layer

package
v0.5.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 29, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Overview

Package layer applies individual image layer tars to a target directory. It detects compressed layer streams, handles whiteout markers and opaque directories, and supports regular files, symlinks and hardlinks.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ApplyLayer

func ApplyLayer(r io.Reader, outputDir string, buf []byte) ([]fsutil.DirMetadata, error)

func HandleWhiteout

func HandleWhiteout(outputDir, entryName string) (bool, error)

func OpenLayerReader

func OpenLayerReader(r io.Reader) (io.Reader, func(), error)

Types

This section is empty.

Jump to